# Definitions of classes and functions

from math import * #math import that allows us using some mathematical functions

class BeamClass:
    x0 = 0 #origin x coordinate
    y0 = 0 #origin y coordinate
    z0 = 0 #origin z coordinate
    span = 6 #beam length
    width = 0.4 #beam width
    depth = 0.6 #beam depth
    name = "Concrete Beam" #name that we want to give to the block created in DIANA
    typeOfConcrete = "C45/55" #class of concrete that we want to use for the simulation
    pass #where the declaration of variables ends before giving name to the class
Beam = BeamClass() #we establish the name to call all the variables once they've been defined

class SteelPlateClass:
    y0 = Beam.y0 #origin y coordinate
    z0 = Beam.depth #origin z coordinate
    span = 0.2 #span of the plate
    width = Beam.width #width of the plate
    depth = 0.05 #depth of the plate
    name = "Steel Plate" #name that we want to give to the second block created
    typeOfSteel = "S275" #kind of steel that we want to use for the simulation
    pass #where the declaration of variables ends before giving name to the class
SteelPlate = SteelPlateClass() #we establish the name to call all the variables once they've been defined
SteelPlate.x0 = Beam.span / 2 - SteelPlate.span / 2 #origin x coordinate. We declare it after the class has been created because some variables created inside are needed.

class PointClass:
        x = Beam.span / 2 #x coordinate
        y = Beam.width / 2 #y coordinate
        z = Beam.depth + SteelPlate.depth #z coordinate
        name = "Point" #name that we want to give to the point created
        pass #where the declaration of variables ends before giving name to the class
Point = PointClass #we establish the name to call all the variables once they've been defined

class CoversClass:
    vertical = 0.1 #vertical cover
    horizontal = 0.1 #horizontal cover
    pass #where the declaration of variables ends before giving name to the class
Covers = CoversClass() #we establish the name to call all the variables once they've been defined

class RebarClass: #we declare the class REBAR.
    distance_between = 0.1 #distance between the horizontal bars.
    x = Beam.x0 #x coordinate where the rebar has to start (it is the same as where the beam starts)
    y = Covers.horizontal  # initial position in Y axis where the first rebar will be
    z_inferior = Covers.vertical  # position in Z axis where the inferior rebar will be
    z_superior = Beam.depth - Covers.vertical  # position in Z axis where the superior rebar will be
    name = "Rebar" #name that we want to give to all the bars created
    young_modulus = 2e+11 #value of the young's modulus of the steel
    yield_stress = 5e+8 #value of the yield stress of the steel
    diametre = 0.012 #value of the diametre of the bars
    name_diametre = "Diametre Rebar" #name that we want to give to the diametre defined before
    pass #where the declaration of variables ends before giving name to the class
Rebar = RebarClass() #we establish the name to call all the variables once they've been defined
Rebar.number_inferior = (ceil(Beam.width / Rebar.distance_between)) - 1  # number of bars in the inferior part
Rebar.number_total = 2 * Rebar.number_inferior  # total number of bars (inferior+superior)
#they're both declared after the class has been named because some variables included inside were needed.

class StirrupsClass:
    distance_between = 0.25 #distance between stirrups
    name = "Stirrup"
    #we define the positions of the points of the polyline
    x = Beam.x0  # this is where the first stirrup will be in the X axis
    y1 = Covers.horizontal #coordinate y of the first and fourth points
    y2 = Beam.width - Covers.horizontal #coordinate y of the second and third points
    z1 = Covers.vertical #coordinate z of the first and second points
    z2 = Beam.depth - Covers.vertical #coordinate z of the third and fourth points
    diametre = 0.008 #we declare the diametre of the stirrups
    name_diametre = "Diametre Stirrups" #we declare the name we want to give to all the created bars
    pass #where the declaration of variables ends before giving name to the class
Stirrups = StirrupsClass() #we establish the name to call all the variables once they've been defined
Stirrups.number = (int(Beam.span / Stirrups.distance_between)) + 1 #we count all the stirrups needed for the beam

class LoadsClass:
    pointload = 1000  #force in Newtons
    pointload_direction = 3 #1 stands for x, 2 for y and 3 for z
    pointload_name = "Point Load" #name of the point load applied
    selfweight_name = "Self weight"#name of the selfweight applied
    pass #where the declaration of variables ends before giving name to the class
Loads = LoadsClass() #we establish the name to call all the variables once they've been defined

class CategoriesClass:
    beams = "Beams" #we give name to the general category that includes the beam
    plates = "Plates" #we give name to the general category that includes the steel plate
    rebar = "Rebar" #we give name to the general category that includes all the rebar
    stirrups = "Stirrups" #we give name to the general category that includes all the stirrups
    pass #where the declaration of variables ends before giving name to the class
Categories = CategoriesClass() #we establish the name to call all the variables once they've been defined

class MaterialsClass:
    concrete = "Concrete" #name of the material 1
    steel = "Steel" #name of the material 2
    reinfo_steel = "Reinforcement steel" #name of the material 3
    pass #where the declaration of variables ends before giving name to the class
Materials = MaterialsClass() #we establish the name to call all the variables once they've been defined

class SupportsClass:
    name = "Supports" #name of the general category
    x_translation = 0 #a 0 will mean the translation can take place. A 1 will mean that it is impeded
    y_translation = 0
    z_translation = 1
    x_rotation = 0
    y_rotation = 0
    z_rotation = 0
    pass #where the declaration of variables ends before giving name to the class
Supports = SupportsClass() #we eestablish the name to call all the variables once they've been defined

class PrincipalAxisClass: #numbers that correspond to the principal axis. Cannot be changed
    x = 1 #we want the user to know what number corresponds to each axis
    y = 2
    z = 3
    pass #where the declaration of variables ends before giving name to the class
PrincipalAxis = PrincipalAxisClass() #we establish the name to call all the variables once they've been defined

class FactorCombinationClass:
    c1 = 1 #just point-load applied
    c2 = 2 #just self-weight applied
    c3 = 3 #point-load+self-weight applied
    pass #where the declaration of variables ends before giving name to the class
FactorCombination = FactorCombinationClass() #we establish the name to call all the variables once they've been defined

class MeshPropertiesClass:
    size = 0.1 #we define the size of cubes of the mesh
    pass #where the declaration of variables ends before giving name to the class
MeshProperties = MeshPropertiesClass() #we establish the name to call all the variables once they've been defined

class AnalysisClass:
    name = "Analysis 1" #name of the analysis
    type = "Structural nonlinear" #type of analysis that we will run
    factor_and_numberIterations = "4(60)" #the first number is the factor and the one in the parenthesis is the nº of iterations
    number_iterations_calculation = 10 #number of iterations DIANA will do for every load-step
    pass #where the declaration of variables ends before giving name to the class
Analysis = AnalysisClass() #we establish the name to call all the variables once they've been defined
